@@ -1,5 +1,7 @@
 from channels.generic.websocket import AsyncJsonWebsocketConsumer
 
+from notification.utils import get_group_name
+
 
 class NotificationConsumer(AsyncJsonWebsocketConsumer):
     """
@@ -9,22 +11,26 @@ class NotificationConsumer(AsyncJsonWebsocketConsumer):
     behind database_sync_to_async or sync_to_async. For more, read
     http://channels.readthedocs.io/en/latest/topics/consumers.html
     """
-    def get_group_name(self):
-        return f'notify-{self.scope["user"].pk}'
 
     async def connect(self):
-        await self.channel_layer.group_add(self.get_group_name(), self.channel_name)
+        await self.channel_layer.group_add(
+            get_group_name(self.scope["user"].pk), self.channel_name
+        )
         await self.accept()
 
     async def disconnect(self, close_code):
-        await self.channel_layer.group_discard(self.get_group_name(), self.channel_name)
+        await self.channel_layer.group_discard(
+            get_group_name(self.scope["user"].pk), self.channel_name
+        )
 
     async def notify_message(self, event):
         """
         Send message to WebSocket
         """
-        await self.send_json({
-            'msgtype': event['msgtype'],
-            'title': event['title'],
-            'message': event['message'],
-        })
+        await self.send_json(
+            {
+                "msgtype": event["msgtype"],
+                "title": event["title"],
+                "message": event["message"],
+            }
+        )
